Struct network_builder::builder::NetworkBuilder [−][src]
pub struct NetworkBuilder { /* fields omitted */ }Expand description
Build Network module with custom configuration values.
Methods can be chained in order to set the configuration values.
MempoolNetworkHandler and ConsensusNetworkHandler are constructed by calling
NetworkBuilder::build. New instances of NetworkBuilder are obtained
via NetworkBuilder::create.
Implementations
pub fn new(
chain_id: ChainId,
trusted_peers: Arc<RwLock<PeerSet>>,
peer_metadata_storage: Arc<PeerMetadataStorage>,
network_context: NetworkContext,
time_service: TimeService,
listen_address: NetworkAddress,
authentication_mode: AuthenticationMode,
max_frame_size: usize,
enable_proxy_protocol: bool,
network_channel_size: usize,
max_concurrent_network_reqs: usize,
inbound_connection_limit: usize,
inbound_rate_limit_config: Option<RateLimitConfig>,
outbound_rate_limit_config: Option<RateLimitConfig>
) -> Self
pub fn new(
chain_id: ChainId,
trusted_peers: Arc<RwLock<PeerSet>>,
peer_metadata_storage: Arc<PeerMetadataStorage>,
network_context: NetworkContext,
time_service: TimeService,
listen_address: NetworkAddress,
authentication_mode: AuthenticationMode,
max_frame_size: usize,
enable_proxy_protocol: bool,
network_channel_size: usize,
max_concurrent_network_reqs: usize,
inbound_connection_limit: usize,
inbound_rate_limit_config: Option<RateLimitConfig>,
outbound_rate_limit_config: Option<RateLimitConfig>
) -> Self
Return a new NetworkBuilder initialized with default configuration values.
pub fn new_for_test(
chain_id: ChainId,
seeds: PeerSet,
trusted_peers: Arc<RwLock<PeerSet>>,
network_context: NetworkContext,
time_service: TimeService,
listen_address: NetworkAddress,
authentication_mode: AuthenticationMode,
peer_metadata_storage: Arc<PeerMetadataStorage>
) -> NetworkBuilder
pub fn create(
chain_id: ChainId,
role: RoleType,
config: &NetworkConfig,
time_service: TimeService,
reconfig_subscription_service: Option<&mut EventSubscriptionService>,
peer_metadata_storage: Arc<PeerMetadataStorage>
) -> NetworkBuilder
pub fn create(
chain_id: ChainId,
role: RoleType,
config: &NetworkConfig,
time_service: TimeService,
reconfig_subscription_service: Option<&mut EventSubscriptionService>,
peer_metadata_storage: Arc<PeerMetadataStorage>
) -> NetworkBuilder
Create a new NetworkBuilder based on the provided configuration.
Create the configured Networking components.
Add a [ConnectivityManager] to the network.
[ConnectivityManager] is responsible for ensuring that we are connected
to a node iff. it is an eligible node and maintaining persistent
connections with all eligible nodes. A list of eligible nodes is received
at initialization, and updates are received on changes to system membership.
Note: a connectivity manager should only be added if the network is permissioned.
pub fn add_p2p_service<SenderT: NewNetworkSender, EventsT: NewNetworkEvents>(
&mut self,
config: &AppConfig
) -> (SenderT, EventsT)
pub fn add_p2p_service<SenderT: NewNetworkSender, EventsT: NewNetworkEvents>(
&mut self,
config: &AppConfig
) -> (SenderT, EventsT)
Register a new Peer-to-Peer (both client and service) application with network and return the specialized client and service interfaces.
Register a new client application with network. Return the client interface for sending messages via network.
Register a new service application with network. Return the service interface for handling new requests from network.